nbxmpp

Package nbxmpp |
[hide private]
[frames] | no frames]

# Source Code for Package nbxmpp

     1  # $Id: __init__.py,v 1.9 2005/03/07 09:34:51 snakeru Exp $
     2
     3  """
     4  This is a fork of the xmpppy jabber python library. Most of the code is
     5  inherited but has been extended by implementation of non-blocking transports
     6  and new features like BOSH.
     7
     8  Most of the xmpp classes are ancestors of PlugIn class to share a single set of methods in order to compile a featured and extensible XMPP client.
     9
    10  Thanks and credits to the xmpppy developers. See: http://xmpppy.sourceforge.net/
    11  """
    12
    13  from protocol import *
    14  import simplexml, protocol, auth_nb, transports_nb, roster_nb
    15  import dispatcher_nb, features_nb, idlequeue, bosh, tls_nb, proxy_connectors
    16  from client_nb import NonBlockingClient
    17  from plugin import PlugIn
    18  from smacks import Smacks
    19